@@ -81,7 +81,6 @@ def output_options(fn):
                 help="Table format - one of {}".format(
                     ", ".join(tabulate.tabulate_formats)
                 ),
-                default="simple",
             ),
             click.option(
                 "--json-cols",
@@ -192,8 +191,8 @@ def tables(
                 row.append(db[name].schema)
             yield row
 
-    if table:
-        print(tabulate.tabulate(_iter(), headers=headers, tablefmt=fmt))
+    if table or fmt:
+        print(tabulate.tabulate(_iter(), headers=headers, tablefmt=fmt or "simple"))
     elif csv or tsv:
         writer = csv_std.writer(sys.stdout, dialect="excel-tab" if tsv else "excel")
         if not no_headers:
@@ -305,6 +304,26 @@ def rebuild_fts(path, tables, load_extension):
             db[table].rebuild_fts()
 
 
+@cli.command()
+@click.argument(
+    "path",
+    type=click.Path(exists=True, file_okay=True, dir_okay=False, allow_dash=False),
+    required=True,
+)
+@click.argument("names", nargs=-1)
+def analyze(path, names):
+    """Run ANALYZE against the whole database, or against specific named indexes and tables"""
+    db = sqlite_utils.Database(path)
+    try:
+        if names:
+            for name in names:
+                db.analyze(name)
+        else:
+            db.analyze()
+    except sqlite3.OperationalError as e:
+        raise click.ClickException(e)
+
+
 @cli.command()
 @click.argument(
     "path",
@@ -471,8 +490,15 @@ def index_foreign_keys(path, load_extension):
     default=False,
     is_flag=True,
 )
+@click.option(
+    "--analyze",
+    help="Run ANALYZE after creating the index",
+    is_flag=True,
+)
 @load_extension_option
-def create_index(path, table, column, name, unique, if_not_exists, load_extension):
+def create_index(
+    path, table, column, name, unique, if_not_exists, analyze, load_extension
+):
     """
     Add an index to the specified table covering the specified columns.
     Use "sqlite-utils create-index mydb -- -column" to specify descending
@@ -487,7 +513,11 @@ def create_index(path, table, column, name, unique, if_not_exists, load_extensio
             col = DescIndex(col[1:])
         columns.append(col)
     db[table].create_index(
-        columns, index_name=name, unique=unique, if_not_exists=if_not_exists
+        columns,
+        index_name=name,
+        unique=unique,
+        if_not_exists=if_not_exists,
+        analyze=analyze,
     )
 
 
@@ -630,6 +660,50 @@ def reset_counts(path, load_extension):
     db.reset_counts()
 
 
+_import_options = (
+    click.option(
+        "--flatten",
+        is_flag=True,
+        help='Flatten nested JSON objects, so {"a": {"b": 1}} becomes {"a_b": 1}',
+    ),
+    click.option("--nl", is_flag=True, help="Expect newline-delimited JSON"),
+    click.option("-c", "--csv", is_flag=True, help="Expect CSV input"),
+    click.option("--tsv", is_flag=True, help="Expect TSV input"),
+    click.option(
+        "--lines",
+        is_flag=True,
+        help="Treat each line as a single value called 'line'",
+    ),
+    click.option(
+        "--text",
+        is_flag=True,
+        help="Treat input as a single value called 'text'",
+    ),
+    click.option("--convert", help="Python code to convert each item"),
+    click.option(
+        "--import",
+        "imports",
+        type=str,
+        multiple=True,
+        help="Python modules to import",
+    ),
+    click.option("--delimiter", help="Delimiter to use for CSV files"),
+    click.option("--quotechar", help="Quote character to use for CSV/TSV"),
+    click.option("--sniff", is_flag=True, help="Detect delimiter and quote character"),
+    click.option("--no-headers", is_flag=True, help="CSV file has no header row"),
+    click.option(
+        "--encoding",
+        help="Character encoding for input, defaults to utf-8",
+    ),
+)
+
+
+def import_options(fn):
+    for decorator in reversed(_import_options):
+        fn = decorator(fn)
+    return fn
+
+
 def insert_upsert_options(fn):
     for decorator in reversed(
         (
@@ -643,40 +717,9 @@ def insert_upsert_options(fn):
             click.option(
                 "--pk", help="Columns to use as the primary key, e.g. id", multiple=True
             ),
-            click.option(
-                "--flatten",
-                is_flag=True,
-                help='Flatten nested JSON objects, so {"a": {"b": 1}} becomes {"a_b": 1}',
-            ),
-            click.option("--nl", is_flag=True, help="Expect newline-delimited JSON"),
-            click.option("-c", "--csv", is_flag=True, help="Expect CSV input"),
-            click.option("--tsv", is_flag=True, help="Expect TSV input"),
-            click.option(
-                "--lines",
-                is_flag=True,
-                help="Treat each line as a single value called 'line'",
-            ),
-            click.option(
-                "--text",
-                is_flag=True,
-                help="Treat input as a single value called 'text'",
-            ),
-            click.option("--convert", help="Python code to convert each item"),
-            click.option(
-                "--import",
-                "imports",
-                type=str,
-                multiple=True,
-                help="Python modules to import",
-            ),
-            click.option("--delimiter", help="Delimiter to use for CSV files"),
-            click.option("--quotechar", help="Quote character to use for CSV/TSV"),
-            click.option(
-                "--sniff", is_flag=True, help="Detect delimiter and quote character"
-            ),
-            click.option(
-                "--no-headers", is_flag=True, help="CSV file has no header row"
-            ),
+        )
+        + _import_options
+        + (
             click.option(
                 "--batch-size", type=int, default=100, help="Commit every X records"
             ),
@@ -696,10 +739,6 @@ def insert_upsert_options(fn):
                 type=(str, str),
                 help="Default value that should be set for a column",
             ),
-            click.option(
-                "--encoding",
-                help="Character encoding for input, defaults to utf-8",
-            ),
             click.option(
                 "-d",
                 "--detect-types",
@@ -707,6 +746,11 @@ def insert_upsert_options(fn):
                 envvar="SQLITE_UTILS_DETECT_TYPES",
                 help="Detect types for columns in CSV/TSV data",
             ),
+            click.option(
+                "--analyze",
+                is_flag=True,
+                help="Run ANALYZE at the end of this operation",
+            ),
             load_extension_option,
             click.option("--silent", is_flag=True, help="Do not show progress bar"),
         )
@@ -732,6 +776,7 @@ def insert_upsert_implementation(
     quotechar,
     sniff,
     no_headers,
+    encoding,
     batch_size,
     alter,
     upsert,
@@ -740,10 +785,11 @@ def insert_upsert_implementation(
     truncate=False,
     not_null=None,
     default=None,
-    encoding=None,
     detect_types=None,
+    analyze=False,
     load_extension=None,
     silent=False,
+    bulk_sql=None,
 ):
     db = sqlite_utils.Database(path)
     _load_extensions(db, load_extension)
@@ -758,13 +804,20 @@ def insert_upsert_implementation(
     if pk and len(pk) == 1:
         pk = pk[0]
     encoding = encoding or "utf-8-sig"
-    buffered = io.BufferedReader(file, buffer_size=4096)
-    decoded = io.TextIOWrapper(buffered, encoding=encoding)
+
+    # The --sniff option needs us to buffer the file to peek ahead
+    sniff_buffer = None
+    if sniff:
+        sniff_buffer = io.BufferedReader(file, buffer_size=4096)
+        decoded = io.TextIOWrapper(sniff_buffer, encoding=encoding)
+    else:
+        decoded = io.TextIOWrapper(file, encoding=encoding)
+
     tracker = None
     if csv or tsv:
         if sniff:
             # Read first 2048 bytes and use that to detect
-            first_bytes = buffered.peek(2048)
+            first_bytes = sniff_buffer.peek(2048)
             dialect = csv_std.Sniffer().sniff(first_bytes.decode(encoding, "ignore"))
         else:
             dialect = "excel-tab" if tsv else "excel"
@@ -792,7 +845,7 @@ def insert_upsert_implementation(
     else:
         try:
             if nl:
-                docs = (json.loads(line) for line in decoded)
+                docs = (json.loads(line) for line in decoded if line.strip())
             else:
                 docs = json.load(decoded)
                 if isinstance(docs, dict):
@@ -825,9 +878,14 @@ def insert_upsert_implementation(
                 except TypeError:
                     raise click.ClickException("--convert must return dict or iterator")
         else:
-            docs = (fn(doc) for doc in docs)
+            docs = (fn(doc) or doc for doc in docs)
 
-    extra_kwargs = {"ignore": ignore, "replace": replace, "truncate": truncate}
+    extra_kwargs = {
+        "ignore": ignore,
+        "replace": replace,
+        "truncate": truncate,
+        "analyze": analyze,
+    }
     if not_null:
         extra_kwargs["not_null"] = set(not_null)
     if default:
@@ -838,6 +896,12 @@ def insert_upsert_implementation(
     # Apply {"$base64": true, ...} decoding, if needed
     docs = (decode_base64_values(doc) for doc in docs)
 
+    # For bulk_sql= we use cursor.executemany() instead
+    if bulk_sql:
+        with db.conn:
+            db.conn.cursor().executemany(bulk_sql, docs)
+        return
+
     try:
         db[table].insert_all(
             docs, pk=pk, batch_size=batch_size, alter=alter, **extra_kwargs
@@ -920,10 +984,11 @@ def insert(
     quotechar,
     sniff,
     no_headers,
+    encoding,
     batch_size,
     alter,
-    encoding,
     detect_types,
+    analyze,
     load_extension,
     silent,
     ignore,
@@ -971,14 +1036,15 @@ def insert(
             quotechar,
             sniff,
             no_headers,
+            encoding,
             batch_size,
             alter=alter,
             upsert=False,
             ignore=ignore,
             replace=replace,
             truncate=truncate,
-            encoding=encoding,
             detect_types=detect_types,
+            analyze=analyze,
             load_extension=load_extension,
             silent=silent,
             not_null=not_null,
@@ -1008,11 +1074,12 @@ def upsert(
     quotechar,
     sniff,
     no_headers,
+    encoding,
     alter,
     not_null,
     default,
-    encoding,
     detect_types,
+    analyze,
     load_extension,
     silent,
 ):
@@ -1039,13 +1106,14 @@ def upsert(
             quotechar,
             sniff,
             no_headers,
+            encoding,
             batch_size,
             alter=alter,
             upsert=True,
             not_null=not_null,
             default=default,
-            encoding=encoding,
             detect_types=detect_types,
+            analyze=analyze,
             load_extension=load_extension,
             silent=silent,
         )
@@ -1053,6 +1121,88 @@ def upsert(
         raise click.ClickException(UNICODE_ERROR.format(ex))
 
 
+@cli.command()
+@click.argument(
+    "path",
+    type=click.Path(file_okay=True, dir_okay=False, allow_dash=False),
+    required=True,
+)
+@click.argument("sql")
+@click.argument("file", type=click.File("rb"), required=True)
+@import_options
+@load_extension_option
+def bulk(
+    path,
+    file,
+    sql,
+    flatten,
+    nl,
+    csv,
+    tsv,
+    lines,
+    text,
+    convert,
+    imports,
+    delimiter,
+    quotechar,
+    sniff,
+    no_headers,
+    encoding,
+    load_extension,
+):
+    """
+    Execute parameterized SQL against the provided list of documents.
+    """
+    try:
+        insert_upsert_implementation(
+            path=path,
+            table=None,
+            file=file,
+            pk=None,
+            flatten=flatten,
+            nl=nl,
+            csv=csv,
+            tsv=tsv,
+            lines=lines,
+            text=text,
+            convert=convert,
+            imports=imports,
+            delimiter=delimiter,
+            quotechar=quotechar,
+            sniff=sniff,
+            no_headers=no_headers,
+            encoding=encoding,
+            batch_size=1,
+            alter=False,
+            upsert=False,
+            not_null=set(),
+            default={},
+            detect_types=False,
+            load_extension=load_extension,
+            silent=False,
+            bulk_sql=sql,
+        )
+    except (sqlite3.OperationalError, sqlite3.IntegrityError) as e:
+        raise click.ClickException(str(e))
+
+
+@cli.command(name="create-database")
+@click.argument(
+    "path",
+    type=click.Path(file_okay=True, dir_okay=False, allow_dash=False),
+    required=True,
+)
+@click.option(
+    "--enable-wal", is_flag=True, help="Enable WAL mode on the created database"
+)
+def create_database(path, enable_wal):
+    "Create a new empty database file."
+    db = sqlite_utils.Database(path)
+    if enable_wal:
+        db.enable_wal()
+    db.vacuum()
+
+
 @cli.command(name="create-table")
 @click.argument(
     "path",
@@ -1456,8 +1606,12 @@ def _execute_query(
                 sys.stdout.buffer.write(data)
             else:
                 sys.stdout.write(str(data))
-        elif table:
-            print(tabulate.tabulate(list(cursor), headers=headers, tablefmt=fmt))
+        elif fmt or table:
+            print(
+                tabulate.tabulate(
+                    list(cursor), headers=headers, tablefmt=fmt or "simple"
+                )
+            )
         elif csv or tsv:
             writer = csv_std.writer(sys.stdout, dialect="excel-tab" if tsv else "excel")
             if not no_headers:
@@ -2222,11 +2376,7 @@ def convert(
     try:
         fn = _compile_code(code, imports)
     except SyntaxError as e:
-        raise click.ClickException(
-            "Syntax error in code:\n\n{}\n\n{}".format(
-                textwrap.indent(e.text.strip(), "    "), e.msg
-            )
-        )
+        raise click.ClickException(str(e))
     if dry_run:
         # Pull first 20 values for first column and preview them
         db.conn.create_function("preview_transform", 1, lambda v: fn(v) if v else v)
@@ -2301,6 +2451,8 @@ FILE_COLUMNS = {
     "mtime_iso": lambda p: datetime.utcfromtimestamp(p.stat().st_mtime).isoformat(),
     "ctime_iso": lambda p: datetime.utcfromtimestamp(p.stat().st_ctime).isoformat(),
     "size": lambda p: p.stat().st_size,
+    "stem": lambda p: p.stem,
+    "suffix": lambda p: p.suffix,
 }
 
 
