@@ -1,6 +1,8 @@
 from sqlite_utils import cli, Database
 from sqlite_utils.db import Index, ForeignKey
 from click.testing import CliRunner
+import subprocess
+import sys
 from unittest import mock
 import json
 import os
@@ -112,10 +114,10 @@ def test_tables_schema(db_path):
 
 
 @pytest.mark.parametrize(
-    "fmt,expected",
+    "options,expected",
     [
         (
-            "simple",
+            ["--fmt", "simple"],
             (
                 "c1     c2     c3\n"
                 "-----  -----  ----------\n"
@@ -126,7 +128,18 @@ def test_tables_schema(db_path):
             ),
         ),
         (
-            "rst",
+            ["-t"],
+            (
+                "c1     c2     c3\n"
+                "-----  -----  ----------\n"
+                "verb0  noun0  adjective0\n"
+                "verb1  noun1  adjective1\n"
+                "verb2  noun2  adjective2\n"
+                "verb3  noun3  adjective3"
+            ),
+        ),
+        (
+            ["--fmt", "rst"],
             (
                 "=====  =====  ==========\n"
                 "c1     c2     c3\n"
@@ -140,7 +153,7 @@ def test_tables_schema(db_path):
         ),
     ],
 )
-def test_output_table(db_path, fmt, expected):
+def test_output_table(db_path, options, expected):
     db = Database(db_path)
     with db.conn:
         db["rows"].insert_all(
@@ -153,7 +166,7 @@ def test_output_table(db_path, fmt, expected):
                 for i in range(4)
             ]
         )
-    result = CliRunner().invoke(cli.cli, ["rows", db_path, "rows", "-t", "--fmt", fmt])
+    result = CliRunner().invoke(cli.cli, ["rows", db_path, "rows"] + options)
     assert 0 == result.exit_code
     assert expected == result.output.strip()
 
@@ -211,6 +224,17 @@ def test_create_index(db_path):
     )
 
 
+def test_create_index_analyze(db_path):
+    db = Database(db_path)
+    assert "sqlite_stat1" not in db.table_names()
+    assert [] == db["Gosh"].indexes
+    result = CliRunner().invoke(
+        cli.cli, ["create-index", db_path, "Gosh", "c1", "--analyze"]
+    )
+    assert result.exit_code == 0
+    assert "sqlite_stat1" in db.table_names()
+
+
 def test_create_index_desc(db_path):
     db = Database(db_path)
     assert [] == db["Gosh"].indexes
@@ -876,6 +900,20 @@ def test_upsert(db_path, tmpdir):
     ]
 
 
+def test_upsert_analyze(db_path, tmpdir):
+    db = Database(db_path)
+    db["rows"].insert({"id": 1, "foo": "x", "n": 3}, pk="id")
+    db["rows"].create_index(["n"])
+    assert "sqlite_stat1" not in db.table_names()
+    result = CliRunner().invoke(
+        cli.cli,
+        ["upsert", db_path, "rows", "-", "--nl", "--analyze", "--pk", "id"],
+        input='{"id": 2, "foo": "bar", "n": 1}',
+    )
+    assert 0 == result.exit_code, result.output
+    assert "sqlite_stat1" in db.table_names()
+
+
 def test_upsert_flatten(tmpdir):
     db_path = str(tmpdir / "flat.db")
     db = Database(db_path)
@@ -2017,3 +2055,68 @@ def test_integer_overflow_error(tmpdir):
         "sql = INSERT INTO [items] ([bignumber]) VALUES (?);\n"
         "parameters = [34223049823094832094802398430298048240]\n"
     )
+
+
+def test_python_dash_m():
+    "Tool can be run using python -m sqlite_utils"
+    result = subprocess.run(
+        [sys.executable, "-m", "sqlite_utils", "--help"], stdout=subprocess.PIPE
+    )
+    assert result.returncode == 0
+    assert b"Commands for interacting with a SQLite database" in result.stdout
+
+
+@pytest.mark.parametrize("enable_wal", (False, True))
+def test_create_database(tmpdir, enable_wal):
+    db_path = tmpdir / "test.db"
+    assert not db_path.exists()
+    args = ["create-database", str(db_path)]
+    if enable_wal:
+        args.append("--enable-wal")
+    result = CliRunner().invoke(cli.cli, args)
+    assert result.exit_code == 0, result.output
+    assert db_path.exists()
+    assert db_path.read_binary()[:16] == b"SQLite format 3\x00"
+    db = Database(str(db_path))
+    if enable_wal:
+        assert db.journal_mode == "wal"
+    else:
+        assert db.journal_mode == "delete"
+
+
+@pytest.mark.parametrize(
+    "options,expected",
+    (
+        (
+            [],
+            [
+                {"tbl": "two_indexes", "idx": "idx_two_indexes_species", "stat": "1 1"},
+                {"tbl": "two_indexes", "idx": "idx_two_indexes_name", "stat": "1 1"},
+                {"tbl": "one_index", "idx": "idx_one_index_name", "stat": "1 1"},
+            ],
+        ),
+        (
+            ["one_index"],
+            [
+                {"tbl": "one_index", "idx": "idx_one_index_name", "stat": "1 1"},
+            ],
+        ),
+        (
+            ["idx_two_indexes_name"],
+            [
+                {"tbl": "two_indexes", "idx": "idx_two_indexes_name", "stat": "1 1"},
+            ],
+        ),
+    ),
+)
+def test_analyze(tmpdir, options, expected):
+    db_path = str(tmpdir / "test.db")
+    db = Database(db_path)
+    db["one_index"].insert({"id": 1, "name": "Cleo"}, pk="id")
+    db["one_index"].create_index(["name"])
+    db["two_indexes"].insert({"id": 1, "name": "Cleo", "species": "dog"}, pk="id")
+    db["two_indexes"].create_index(["name"])
+    db["two_indexes"].create_index(["species"])
+    result = CliRunner().invoke(cli.cli, ["analyze", db_path] + options)
+    assert result.exit_code == 0
+    assert list(db["sqlite_stat1"].rows) == expected
