@@ -2,6 +2,9 @@ from sqlite_utils import cli, Database
 from click.testing import CliRunner
 import json
 import pytest
+import subprocess
+import sys
+import time
 
 
 def test_insert_simple(tmpdir):
@@ -165,7 +168,7 @@ def test_insert_newline_delimited(db_path):
     result = CliRunner().invoke(
         cli.cli,
         ["insert", db_path, "from_json_nl", "-", "--nl"],
-        input='{"foo": "bar", "n": 1}\n{"foo": "baz", "n": 2}',
+        input='{"foo": "bar", "n": 1}\n\n{"foo": "baz", "n": 2}',
     )
     assert 0 == result.exit_code, result.output
     db = Database(db_path)
@@ -324,6 +327,20 @@ def test_insert_alter(db_path, tmpdir):
     ] == list(db.query("select foo, n, baz from from_json_nl"))
 
 
+def test_insert_analyze(db_path):
+    db = Database(db_path)
+    db["rows"].insert({"foo": "x", "n": 3})
+    db["rows"].create_index(["n"])
+    assert "sqlite_stat1" not in db.table_names()
+    result = CliRunner().invoke(
+        cli.cli,
+        ["insert", db_path, "rows", "-", "--nl", "--analyze"],
+        input='{"foo": "bar", "n": 1}\n{"foo": "baz", "n": 2}',
+    )
+    assert 0 == result.exit_code, result.output
+    assert "sqlite_stat1" in db.table_names()
+
+
 def test_insert_lines(db_path):
     result = CliRunner().invoke(
         cli.cli,
@@ -434,3 +451,66 @@ def test_insert_convert_lines(db_path):
     db = Database(db_path)
     rows = list(db.query("select [line] from [all]"))
     assert rows == [{"line": "THIS IS TEXT"}, {"line": "WILL BE UPPER NOW"}]
+
+
+def test_insert_convert_row_modifying_in_place(db_path):
+    result = CliRunner().invoke(
+        cli.cli,
+        [
+            "insert",
+            db_path,
+            "rows",
+            "-",
+            "--convert",
+            'row["is_chicken"] = True',
+        ],
+        input='{"name": "Azi"}',
+    )
+    assert result.exit_code == 0, result.output
+    db = Database(db_path)
+    rows = list(db.query("select name, is_chicken from rows"))
+    assert rows == [{"name": "Azi", "is_chicken": 1}]
+
+
+def test_insert_streaming_batch_size_1(db_path):
+    # https://github.com/simonw/sqlite-utils/issues/364
+    # Streaming with --batch-size 1 should commit on each record
+    # Can't use CliRunner().invoke() here bacuse we need to
+    # run assertions in between writing to process stdin
+    proc = subprocess.Popen(
+        [
+            sys.executable,
+            "-m",
+            "sqlite_utils",
+            "insert",
+            db_path,
+            "rows",
+            "-",
+            "--nl",
+            "--batch-size",
+            "1",
+        ],
+        stdin=subprocess.PIPE,
+        stdout=sys.stdout,
+    )
+    proc.stdin.write(b'{"name": "Azi"}\n')
+    proc.stdin.flush()
+
+    def try_until(expected):
+        tries = 0
+        while True:
+            rows = list(Database(db_path)["rows"].rows)
+            if rows == expected:
+                return
+            tries += 1
+            if tries > 10:
+                assert False, "Expected {}, got {}".format(expected, rows)
+            time.sleep(tries * 0.1)
+
+    try_until([{"name": "Azi"}])
+    proc.stdin.write(b'{"name": "Suna"}\n')
+    proc.stdin.flush()
+    try_until([{"name": "Azi"}, {"name": "Suna"}])
+    proc.stdin.close()
+    proc.wait()
+    assert proc.returncode == 0
